@@ -18,8 +18,13 @@ class CinnamonProfile(XorgProfile):
 			"system-config-printer",
 			"gnome-keyring",
 			"gnome-terminal",
-			"blueberry",
-			"metacity"
+			"blueman",
+			"bluez-utils",
+			"engrampa",
+			"gnome-screenshot",
+			"gvfs-smb",
+			"xed",
+			"xdg-user-dirs-gtk"
 		]
 
 	@property
