@@ -18,7 +18,7 @@ from .device_model import (
 	DeviceModification, PartitionModification,
 	BDevice, _DeviceInfo, _PartitionInfo,
 	FilesystemType, Unit, PartitionTable,
-	ModificationStatus, get_lsblk_info, LsblkInfo,
+	ModificationStatus, get_lsblk_info, find_lsblk_info, LsblkInfo,
 	_BtrfsSubvolumeInfo, get_all_lsblk_info, DiskEncryption, LvmVolumeGroup, LvmVolume, Size, LvmGroupInfo,
 	SectorSize, LvmVolumeInfo, LvmPVInfo, SubvolumeModification, BtrfsMountOption
 )
@@ -47,6 +47,8 @@ class DeviceHandler(object):
 	def load_devices(self):
 		block_devices = {}
 
+		SysCommand('udevadm settle')
+		all_lsblk_info = get_all_lsblk_info()
 		devices = getAllDevices()
 
 		try:
@@ -58,7 +60,11 @@ class DeviceHandler(object):
 			debug(f'Failed to get loop devices: {err}')
 
 		for device in devices:
-			dev_lsblk_info = get_lsblk_info(device.path)
+			dev_lsblk_info = find_lsblk_info(device.path, all_lsblk_info)
+
+			if not dev_lsblk_info:
+				debug(f'Device lsblk info not found: {device.path}')
+				continue
 
 			if dev_lsblk_info.type == 'rom':
 				continue
@@ -76,12 +82,17 @@ class DeviceHandler(object):
 			partition_infos = []
 
 			for partition in disk.partitions:
-				lsblk_info = get_lsblk_info(partition.path)
+				lsblk_info = find_lsblk_info(partition.path, dev_lsblk_info.children)
+
+				if not lsblk_info:
+					debug(f'Partition lsblk info not found: {partition.path}')
+					continue
+
 				fs_type = self._determine_fs_type(partition, lsblk_info)
 				subvol_infos = []
 
 				if fs_type == FilesystemType.Btrfs:
-					subvol_infos = self.get_btrfs_info(partition.path)
+					subvol_infos = self.get_btrfs_info(partition.path, lsblk_info)
 
 				partition_infos.append(
 					_PartitionInfo.from_partition(
@@ -155,8 +166,14 @@ class DeviceHandler(object):
 		partition = self.find_partition(path)
 		return partition.partuuid if partition else None
 
-	def get_btrfs_info(self, dev_path: Path) -> List[_BtrfsSubvolumeInfo]:
-		lsblk_info = get_lsblk_info(dev_path)
+	def get_btrfs_info(
+			self,
+			dev_path: Path,
+			lsblk_info: Optional[LsblkInfo] = None
+	) -> List[_BtrfsSubvolumeInfo]:
+		if not lsblk_info:
+			lsblk_info = get_lsblk_info(dev_path)
+
 		subvol_infos: List[_BtrfsSubvolumeInfo] = []
 
 		if not lsblk_info.mountpoint:
@@ -551,8 +568,6 @@ class DeviceHandler(object):
 	):
 		info(f'Creating subvolumes: {part_mod.safe_dev_path}')
 
-		luks_handler = None
-
 		# unlock the partition first if it's encrypted
 		if enc_conf is not None and part_mod in enc_conf.partitions:
 			if not part_mod.mapper_name:
@@ -567,35 +582,29 @@ class DeviceHandler(object):
 			if not luks_handler.mapper_dev:
 				raise DiskError('Failed to unlock luks device')
 
-			self.mount(
-				luks_handler.mapper_dev,
-				self._TMP_BTRFS_MOUNT,
-				create_target_mountpoint=True,
-				options=part_mod.mount_options
-			)
+			dev_path = luks_handler.mapper_dev
 		else:
-			self.mount(
-				part_mod.safe_dev_path,
-				self._TMP_BTRFS_MOUNT,
-				create_target_mountpoint=True,
-				options=part_mod.mount_options
-			)
+			luks_handler = None
+			dev_path = part_mod.safe_dev_path
+
+		self.mount(
+			dev_path,
+			self._TMP_BTRFS_MOUNT,
+			create_target_mountpoint=True,
+			options=part_mod.mount_options
+		)
 
 		for sub_vol in part_mod.btrfs_subvols:
 			debug(f'Creating subvolume: {sub_vol.name}')
 
-			if luks_handler is not None:
-				subvol_path = self._TMP_BTRFS_MOUNT / sub_vol.name
-			else:
-				subvol_path = self._TMP_BTRFS_MOUNT / sub_vol.name
+			subvol_path = self._TMP_BTRFS_MOUNT / sub_vol.name
 
 			SysCommand(f"btrfs subvolume create {subvol_path}")
 
+		self.umount(dev_path)
+
 		if luks_handler is not None and luks_handler.mapper_dev is not None:
-			self.umount(luks_handler.mapper_dev)
 			luks_handler.lock()
-		else:
-			self.umount(part_mod.safe_dev_path)
 
 	def unlock_luks2_dev(self, dev_path: Path, mapper_name: str, enc_password: str) -> Luks2:
 		luks_handler = Luks2(dev_path, mapper_name=mapper_name, password=enc_password)
