@@ -229,7 +229,16 @@ class Installer:
 		if self._disk_config.lvm_config:
 			pvs = self._disk_config.lvm_config.get_all_pvs()
 
+		sorted_device_mods = self._disk_config.device_modifications.copy()
+
+		# move the device with the root partition to the beginning of the list
 		for mod in self._disk_config.device_modifications:
+			if any(partition.is_root() for partition in mod.partitions):
+				sorted_device_mods.remove(mod)
+				sorted_device_mods.insert(0, mod)
+				break
+
+		for mod in sorted_device_mods:
 			not_pv_part_mods = list(filter(lambda x: x not in pvs, mod.partitions))
 
 			# partitions have to mounted in the right order on btrfs the mountpoint will
@@ -484,7 +493,7 @@ class Installer:
 		if mirrorlist_config:
 			debug(f'Mirrorlist: {mirrorlist_config}')
 
-			with local_mirrorlist_conf.open('a') as fp:
+			with local_mirrorlist_conf.open('w') as fp:
 				fp.write(mirrorlist_config)
 
 	def genfstab(self, flags: str = '-pU'):
@@ -795,10 +804,10 @@ class Installer:
 				self.pacman.strap('libfido2')
 
 				if 'sd-encrypt' not in self._hooks:
-					self._hooks.insert(self._hooks.index('lvm2') - 1, 'sd-encrypt')
+					self._hooks.insert(self._hooks.index('lvm2'), 'sd-encrypt')
 			else:
 				if 'encrypt' not in self._hooks:
-					self._hooks.insert(self._hooks.index('lvm2') - 1, 'encrypt')
+					self._hooks.insert(self._hooks.index('lvm2'), 'encrypt')
 
 	def minimal_installation(
 		self,
@@ -1290,21 +1299,21 @@ Exec = /bin/sh -c "{hook_command}"
 		hook_path.write_text(hook_contents)
 
 		kernel_params = ' '.join(self._get_kernel_params(root))
-		config_contents = 'TIMEOUT=5\n'
+		config_contents = 'timeout: 5\n'
 
 		for kernel in self.kernels:
 			for variant in ('', '-fallback'):
 				entry = [
-					f'PROTOCOL=linux',
-					f'KERNEL_PATH=boot:///vmlinuz-{kernel}',
-					f'MODULE_PATH=boot:///initramfs-{kernel}{variant}.img',
-					f'CMDLINE={kernel_params}',
+					f'protocol: linux',
+					f'kernel_path: boot():/vmlinuz-{kernel}',
+					f'kernel_cmdline: {kernel_params}',
+					f'module_path: boot():/initramfs-{kernel}{variant}.img',
 				]
 
-				config_contents += f'\n:Arch Linux ({kernel}{variant})\n'
+				config_contents += f'\n/Arch Linux ({kernel}{variant})\n'
 				config_contents += '\n'.join([f'    {it}' for it in entry]) + '\n'
 
-		config_path = self.target / 'boot' / 'limine.cfg'
+		config_path = self.target / 'boot' / 'limine.conf'
 		config_path.write_text(config_contents)
 
 		self.helper_flags['bootloader'] = "limine"
